@@ -1,7 +1,9 @@
 import pacsltk.deployer as deployer
 import pacsltk.perfmodel as perfmodel
+import pacsltk.pacs_util as pacs_util
+import pacsltk.exp_parser as exp_parser
 
-__version__ = '0.1.6'
+__version__ = '0.1.8'
 
 __author__ = 'Nima Mahmoudi <nma@ieee.org>'
 
